#!/usr/bin/python
#############################################################################
#
#  Linux Desktop Testing Project http://ldtp.freedesktop.org
# 
#  Author:
#     Alex Yu <tae.ccf@gmail.com>
# 
#  Copyright 2004 - 2006 Palmsource, Inc.
# 
#  This library is free software; you can redistribute it and/or
#  modify it under the terms of the GNU Library General Public
#  License as published by the Free Software Foundation; either
#  version 2 of the License, or (at your option) any later version.
# 
#  This library is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
#  Library General Public License for more details.
# 
#  You should have received a copy of the GNU Library General Public
#  License along with this library; if not, write to the
#  Free Software Foundation, Inc., 59 Temple Place - Suite 330,
#  Boston, MA 02111-1307, USA.
#
#############################################################################


import ldtp, sys, re
import time

args = 'convert <window> <output> [append]'
wrongargs = 'You have specified wrong arguments, the correct are: ' + args

class menuitem:
    def __init__(self, name, parent):
        self.name = name
        self.parent = parent

def getchildmenu(menus):
    result = []
    for i in range(1,len(menus)):
        breaked = 0
        for idx in range(2, len(menus)):
            if menus[idx].parent == menus[i].name:
                breaked = 1
                break

        if breaked == 0:
            result.append(menus[i])
    return result
                
                        
def getallmenus(objs):
    menus = []
    for obj in objs:
        if obj[0:3] == 'mnu' and obj[0:4] != 'mnu0':
            parent = ldtp.getobjectproperty(sys.argv[1], obj, 'parent')
            if parent[0:3] == 'mnu':
                menus.append(menuitem(obj, parent))         
    return menus
    
def linkmenu(menuobj):
    temp = menuobj
    m = ''
    while 1:
        p = ldtp.getobjectproperty(sys.argv[1], temp, 'parent')
        
        if p[0:3] == 'mbr':
            m += menuobj
            return m
        else:
            m = p + ';' + m
            temp = p


def generatemenuitem(childmenus):
    result = []
    for menu in childmenus:
        result.append(linkmenu(menu.name))
    return result

def fillwindow(template):
    windowname_noprefix = sys.argv[1]
    windowname = sys.argv[1]

    result = []

    for line in template:
        tempstr = line.replace('[windowname_noprefix]', windowname_noprefix)
        result.append(tempstr.replace('[windowname]', windowname))
    
    return result
    
def fillwidget(widgets, template):
    result = []
    for widget in widgets:
        widgetname = widget
        tag = widgets[widget]

        for line in widgettemplate:
            tempstr = line.replace('[widgetname]', widgetname)
            tempstr = tempstr.replace('[tag]', tag)

            if widgettype.has_key(widgetname[0:3]):
                wtype =  widgettype[widgetname[0:3]]
                if wtype != '':
                    tempstr = tempstr.replace('[widgetclass]', wtype)
                    result.append(tempstr)

    return result

#=======================================================================================
arglen = len(sys.argv)

if arglen < 3 or arglen > 3:
    print wrongargs
    raise 'wrong arguments'

widgets = {}
objs = ldtp.getobjectlist(sys.argv[1])
for obj in objs:
    print obj

menus = getallmenus(objs)
if menus != '':
    mymenus = getchildmenu(menus)
    finalmenus = generatemenuitem(mymenus)
    finalmenus.sort()

    for menu in finalmenus:
        name = menu.split(';')[-1]
        widgets[name] = (menu)

#get all the other type widgets (beside menu)
for obj in objs:
    if obj[0:3] == 'mnu':
        continue
    else:
        widgets[obj] = obj

title = ['''#!/usr/bin/python\n\n''',
     '''from window import *\n\n''']

windowtemplate = ['''class [windowname_noprefix](Window):\n''',
                  '''        name = '[windowname]'\n''',
                  '''\n''']
widgettemplate = ['''        [widgetname] = Window.[widgetclass]('[tag]', name)\n''']



widgettype = {
            'btn' : 'PushButton',
            'mnu' : 'MenuItem',
            'txt' : 'Text',
            'chk' : 'CheckBox',
            'cbo' : 'ComboBox',
            'lst' : 'List',
            'rdo' : 'RadioButton',
            'tbl' : 'Table'
            }


output = open(sys.argv[2], 'w')
output.writelines(title)
output.writelines(fillwindow(windowtemplate))

lines = fillwidget(widgets, widgettemplate)
lines.sort()
output.writelines(lines)
output.close()
